==> alfred-ui-native-components-0.0.159.tgz: package/ui/molecules/sliders/booleanSlider/index.tsx <==
import React, { FC, useEffect, useState } from 'react';
import { View } from 'react-native';
import { Slider } from '@miblanchard/react-native-slider';
import { BooleanIconTrack } from '../../../atoms/track/booleanIconTrack';
import { SliderModel } from '../sliderModels';
import { styles } from '../styles';

export const BooleanSlider: FC<SliderModel> = ({
  ThumbComponent,
  IconLeft,
  IconRight,
  onStateChange,
  defaultValue = 0,
}) => {
  const [value, setValue] = useState<number>(defaultValue);

  useEffect(() => {
    setValue(defaultValue);
  }, [defaultValue]);

  useEffect(() => {
    // onStateChange && onStateChange(value);
  }, [value]);

  const onFinishSlide = (val: number | number[]) => {
    const sliderValue = Array.isArray(val) ? val[0] : val;
    sliderValue === 1 ? setValue(1) : setValue(0);
    onStateChange?.(value);
  };

  const handleChangeValue = (val: number | number[]) => {
    const sliderValue = Array.isArray(val) ? val[0] : val;
    setValue(sliderValue);
  };

  return (
    <View testID={'BooleanSlider'}>
      <BooleanIconTrack IconLeft={IconLeft} IconRight={IconRight} />
      <Slider
        animateTransitions
        renderThumbComponent={ThumbComponent}
        trackStyle={styles().sliderTrack}
        minimumTrackTintColor={'#FFFFFF00'}
        trackClickable={false}
        minimumValue={0}
        maximumValue={1}
        value={value}
        onValueChange={handleChangeValue}
        onSlidingComplete={onFinishSlide}
        thumbTouchSize={{
          width: 40,
          height: 60,
        }}
      />
    </View>
  );
};

==> alfred-ui-native-components-0.0.166.tgz: package/ui/molecules/sliders/booleanSlider/index.tsx <==
import React, { FC, useEffect, useState } from 'react';
import { View } from 'react-native';
import { Slider } from '@miblanchard/react-native-slider';
import { BooleanIconTrack } from '../../../atoms/track/booleanIconTrack';
import { SliderModel } from '../sliderModels';
import { styles } from '../styles';

export const BooleanSlider: FC<SliderModel> = ({
  ThumbComponent,
  IconLeft,
  IconRight,
  onStateChange,
  defaultValue = 0,
}) => {
  const [value, setValue] = useState<number>(defaultValue);

  useEffect(() => {
    setValue(defaultValue);
  }, [defaultValue]);

  useEffect(() => {
    // onStateChange && onStateChange(value);
  }, [value]);

  const Component = () => <ThumbComponent />;

  const onFinishSlide = (val: number | number[]) => {
    const sliderValue = Array.isArray(val) ? val[0] : val;
    sliderValue === 1 ? setValue(1) : setValue(0);
    onStateChange?.(value);
  };

  const handleChangeValue = (val: number | number[]) => {
    const sliderValue = Array.isArray(val) ? val[0] : val;
    setValue(sliderValue);
  };

  return (
    <View testID={'BooleanSlider'}>
      <BooleanIconTrack IconLeft={IconLeft} IconRight={IconRight} />
      <Slider
        animateTransitions
        renderThumbComponent={Component}
        trackStyle={styles().sliderTrack}
        minimumTrackTintColor={'#FFFFFF00'}
        trackClickable={false}
        minimumValue={0}
        maximumValue={1}
        value={value}
        onValueChange={handleChangeValue}
        onSlidingComplete={onFinishSlide}
        thumbTouchSize={{
          width: 40,
          height: 60,
        }}
      />
    </View>
  );
};
